// Copyright 2024 schukai GmbH
// SPDX-License-Identifier: proprietary

package watch

import (
	"fmt"
)

// WatchPathError represents an error when trying to remove an unwatched path.
type UnwatchedPathError struct {
	UnwatchedPath string
}

func (e UnwatchedPathError) Error() string {
	return fmt.Sprintf("Path %s is not being watched", e.UnwatchedPath)
}

// WatchPathError represents an error when trying to add a path that is already being watched.
type AlreadyWatchedPathError struct {
	AlreadyWatched string
}

func (e AlreadyWatchedPathError) Error() string {
	return fmt.Sprintf("Path %s is already being watched", e.AlreadyWatched)
}

// WatcherNotActiveError represents an error when trying to add a path that is already being watched.
type WatcherNotActiveError struct{}

func (e WatcherNotActiveError) Error() string {
	return "Watcher is not active"
}

// WatcherNotActiveError represents an error when trying to add a path that is already being watched.
type WatcherNotRunningError struct{}

func (e WatcherNotRunningError) Error() string {
	return "Watcher is not active"
}

// WatcherAlreadyRunningError represents an error when trying to add a path that is already being watched.
type WatcherAlreadyRunningError struct{}

func (e WatcherAlreadyRunningError) Error() string {
	return "Watcher is already running"
}

// LighthouseNotActiveError represents an error when trying to add a path that is already being watched.
type LighthouseNotActiveError struct{}

func (e LighthouseNotActiveError) Error() string {
	return "lighthouse is not active"
}

// WatcherNotActiveError represents an error when trying to add a path that is already being watched.
type WatcherAlreadyActiveError struct{}

func (e WatcherAlreadyActiveError) Error() string {
	return "Watcher is already active"
}

type PathNotExistingError struct {
	Path string
}

func (e PathNotExistingError) Error() string {
	return fmt.Sprintf("Path %s does not exist", e.Path)
}
