// Copyright 2024 schukai GmbH
// SPDX-License-Identifier: proprietary

package watch

import (
	"github.com/stretchr/testify/assert"
	"os"
	"testing"
)

func TestMultipleWatcher(t *testing.T) {
	watcher1 := NewWatcher()
	watcher2 := NewWatcher()

	defer watcher1.Stop()
	defer watcher2.Stop()

	assert.NotEqual(t, watcher1, watcher2)
}

func TestMultipleWatcherDoesNotShareCache(t *testing.T) {
	watcher1 := NewWatcher()
	watcher2 := NewWatcher()

	defer watcher1.Stop()
	defer watcher2.Stop()

	testfiles := []string{}
	for i := 0; i < 100; i++ {
		testfile, err := os.CreateTemp("", "testfile")
		if err != nil {
			t.Fatal("Failed to create test file:", err)
		}
		testfiles = append(testfiles, testfile.Name())

		defer func() {
			_ = os.Remove(testfile.Name())
		}()
	}

	for _, testfile := range testfiles {
		_ = os.WriteFile(testfile, []byte("test"), 0644)
		_ = watcher1.Add(testfile)

		_, ok := watcher2.cache.Load(testfile)
		assert.False(t, ok)
	}

	for _, testfile := range testfiles {
		_ = watcher2.Remove(testfile)
		_, ok := watcher2.cache.Load(testfile)
		assert.False(t, ok)
		_, ok = watcher1.cache.Load(testfile)
		assert.True(t, ok)
	}

}
