{pkgs', ...}: let
  bashFktScript = import ./bash-fkt.nix {
    inherit pkgs';
  };
in
  pkgs'.writeShellScriptBin "update-manual-summary" ''

    source ${pkgs'.common}/bin/common
    ${bashFktScript}

    echo_section "Update manual summary"
    echo_hint "This script will update the SUMMARY.md file with the files in the manual directory."
    echo_hint "The command is executed in the current working directory and not in a nix derivation."
    cd_working_dir

    echo_step "Updating summary file..."

    doc_dir="documentation/manual/de/source/"
    summary_file="''${doc_dir}SUMMARY.md"

    echo "# Summary" > "$summary_file"
    echo "" >> "$summary_file"

    extract_first_h1() {
        local file_path="$1"

        ${pkgs'.gnused}/bin/sed -n '/^# /{
        s/^# //;
        s/[()]//g;
        s/\\n//g;
        s/\\r//g;
        s/\\t//g;
        p;
        q;
        }' "$file_path"

    }


    generate_summary() {
        local path="$1"
        local indent="$2"
        local rel_path="''${path#$doc_dir}"

        for item in "$path"/*; do
            if [ -d "$item" ]; then
                # Es ist ein Verzeichnis#
                dirname=$(${pkgs'.coreutils}/bin/basename "$item")
                md_files=$(${pkgs'.findutils}/bin/find "$item" -maxdepth 1 -type f -name '*.md')

                subdir_count=$(${pkgs'.findutils}/bin/find "$item" -mindepth 1 -maxdepth 1 -type d | wc -l)

                if [ ! -z "$md_files" ] || [ $subdir_count -gt 0 ]; then
                    main_doc=$(${pkgs'.findutils}/bin/find "$item" -maxdepth 1 -type f \( -name 'index.md' -o -name 'README.md' \) | ${pkgs'.coreutils}/bin/head -n 1)
                    if [ -n "$main_doc" ]; then
                        main_doc_filename=$(${pkgs'.coreutils}/bin/basename "$main_doc")
                        echo "''${indent}* [''${dirname^}](''${rel_path#/}/''${dirname}/''${main_doc_filename})" >> "$summary_file"
                    else
                        echo "''${indent}*  [''${dirname^}]()" >> "$summary_file"
                    fi
                    generate_summary "$item" "''${indent}    "
                fi
            elif [[ "$item" == *.md ]]; then
                filename=$(${pkgs'.coreutils}/bin/basename "$item")
                title="''${filename%.*}"

                h1=$(extract_first_h1 "$item")

                if [ -n "$h1" ]; then
                    title="$h1"
                fi

                echo "''${indent}* [''${title}](''${rel_path#/}/''${filename})" >> "$summary_file"
            fi
        done
    }

    generate_summary "$doc_dir" ""

    ## remopve all lines with imprint.md and privacy.md and 404.md
    ${pkgs'.gnused}/bin/sed -i '/\(imprint\.md\|privacy\.md\|404\.md\|SUMMARY.md\)/d' "$summary_file"

    echo "---" >> "$summary_file"
    echo "* [imprint](imprint.md)" >> "$summary_file"


    echo_ok "SUMMARY.md updated successfully."
    echo_hint "Use task watch-manual to check the manual for errors."
    echo_hint "Please check the file for correctness and commit the changes."

  ''
